use utf8;
package Acme::3mxA;

sub import {
  Acme::ǝmɔA->import;
}

"með blóðnasir"

__END__

=encoding utf-8

=head1 NAME

Acme::3mxA - Turn your perl upside down

=head1 SYNOPSIS

  use utf8; use Acme::ǝmɔA;

  ɹǝpun uʍop ʍou ǝɹ,no⅄ #

=head1 DESCRIPTION

Turns your perl code upside down.

This is yet another Acme module that does something amusing yet useless to your
code. I'm afraid I couldn't resist.

Note the name of this module was originally L<Acme::ǝmɔA>, unfortunately        
search.cpan.org stopped displaying the docs for this at some point. Plus the    
module was mostly uninstallable via CPAN clients. So I reluctantly have made    
Acme::3mxA an alias for this.                           

=head1 BUGS

The bug density is so high this module has ceased existing and is now held
together by the bugs that are crawling through it.

=over 4

=item *

Source filter usage means __DATA__ and probably other things don't work.

=item *

Assumes UTF-8 in places it probably shouldn't.

=back

=head1 SEE ALSO

L<Acme::Bleach> which started it all, L<Acme::Palindrome>, L<Acme::emcA>
and L<Acme::Ünicöde> which appears to have pioneered Unicode package names.

=head1 LICENCE

There is no warranty for this code. You really do use it at your own risk.

      DO WHAT THE FUCK YOU WANT TO PUBLIC LICENSE
                   Version 2, December 2004

  Copyright (C) 2004 Sam Hocevar
   14 rue de Plaisance, 75014 Paris, France
  Everyone is permitted to copy and distribute verbatim or modified
  copies of this license document, and changing it is allowed as long
  as the name is changed.

           DO WHAT THE FUCK YOU WANT TO PUBLIC LICENSE
  TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION

  0. You just DO WHAT THE FUCK YOU WANT TO.

=head1 AUTHOR

David Leadbeater <dgl@dgl.cx>

=cut
