#!/usr/bin/env perl
                                                                use lib qw(lib);
                                                        use utf8;use Acme::ǝmɔA;
                                                                                
                                                         ؛ʇdıɹɔs‾pʃınq‾ǝʇɐǝɹɔ<-(
                                             'bǝɹ‾pʃınq$ <= sǝɹınbǝɹ‾ǝɹnƃıɟuoɔ  
                                             'bǝɹ‾pʃınq$ <=     sǝɹınbǝɹ‾pʃınq  
                                             'bǝɹ‾pʃınq$ <=           sǝɹınbǝɹ  
                                                ',ʃdɟʇʍ, <=            ǝsuǝɔıʃ  
                                           ',∀xɯƐ::ǝɯɔ∀, <=        ǝɯɐu‾ǝʃnpoɯ  
                                                '7Ɛ˙7ƐƐ1 <=       uoısɹǝʌ‾ʇsıp  
                                                                         )ʍǝu<-(
                                                 'ʃdɟʇʍ$ <=               ǝpoɔ  
                                          ',ɹǝpʃınξ::ʎW, <=              ssɐʃɔ  
                                                        )ssɐʃɔqns<-pʃınξ::ǝʃnpoW
                                                                                
                                                                              ؛{
                                                      '0 <= ,uʍo◖ǝpısd∩::ʇxǝ⊥,  
                                                      '0 <=   ,ǝʃdɯıS::ɹǝʇʃıℲ,  
                                                ',6˙8˙5, <=               ʃɹǝd  
                                                      '0 <=          ɹǝʞʃɐMpɐԀ  
                                                               } = bǝɹ‾pʃınq$ ʎɯ
                                                                                
                                                                    ؛ʃdɟʇʍ$ ʃɐʌǝ
                                                                             ℲOƎ
                                                                 ˙ʍou sı ʇı˙˙˙ #
؛2 = {ʃdɟʇʍ}<-{,sǝsuǝɔıʃ%,}<-((„sǝsuǝɔıʃ‾pıʃɐʌ„)uɐɔ<-pʃınξ::ǝʃnpoW)qns‾ʞǝǝd::ɹǝʞʃɐMpɐԀ
                                                                  ؛ɹǝʞʃɐMpɐԀ ǝsn
   ˙˙˙os 'ǝʃnpoɯ ǝɯɔ∀ uɐ sı sıɥʇ 'ʃʃǝʍ 'ǝsuǝɔıʃ pıʃɐʌ ɐ ʇ,usı ⅂ԀℲ⊥M ʎʃʇuǝɹɐdd∀ #
                                                            ؛,ℲOƎ,>> = ʃdɟʇʍ$ ʎɯ
                                                                                
                                                              ؛pʃınξ::ǝʃnpoW ǝsn
