#!perl
my $what = "Just a test of some common constructs.";

                                                        use utf8;use Acme::ǝmɔA;
                                                                                
                                                                          ؛()zɐq
                                                                          ؛()ɹɐq
                                                                          ؛()ooɟ
                                                                                
                                                                               {
              ؛ʇɐɥʍ$ '(„Just a test of some common constructs.„)uʍop‾ǝpısdn sı  
                                                    ؛„uʍo◖ǝpısd∩::ʇxǝ⊥„ ʞo‾ǝsn  
                                                                       } zɐq qns
                                                                                
                                                                               {
                                                                           ؛„   
                                                                   x   „ bǝ „   
                                                                      x   „ ʞo  
                                                                                
                                                                            ؛1  
                                                                        ==      
                                                                          1 ʞo  
                                                                       } ɹɐq qns
                                                                                
                                                                            ʇnɔ=
                                                                                
                                                                   ǝɹǝɥ pod ǝɯos
                                                                                
                                                                   ʇsǝʇ ɐ 1pɐǝɥ=
                                                                                
                                                                               {
                                                                             {  
                                                                      ؛‾$ ʞo    
                                                                 } (9 ˙˙ 1)ɹoɟ  
                                                                       } ooɟ qns
                                                                                
                                                     ؛01 <= sʇsǝʇ ǝɹoW::ʇsǝ⊥ ǝsn
